package es.upv.epsa.centro_veterinario.entidades;

import java.util.ArrayList;
import java.util.List;

import com.google.common.collect.ImmutableList;
import com.googlecode.objectify.annotation.Cache;
import com.googlecode.objectify.annotation.Entity;
import com.googlecode.objectify.annotation.Id;

/**
 * Clase java para la entidad perfil del usuario
 * @author Ana Olcina
 * TFG 2017
 *
 */

@Entity
@Cache
public class Perfil {
	/**
	 * Datos del perfil
	 */
	String nombre;
	String direccion;
	String poblacion;
	String provincia;
	String codigo_postal;
	String telefono;
	String movil;
	String email;

    /**
     * El id será la clave del registro del datastore.
     */
	@Id
	String userId;
	
	/**
	 * Claves de las mascotas del usuario
	 */
    private List<String> mascotasPropiasKeys = new ArrayList<>(0);
    
	/**
	 * Claves de las visitas del usuario
	 */
    private List<String> visitasPropiasKeys = new ArrayList<>(0);
    
    /**
     * Constructor por defecto
     */
    private Perfil() {}
    
	/**
	 * Constructor del perfil
	 * @param userId
	 * @param nombre
	 * @param direccion
	 * @param poblacion
	 * @param provincia
	 * @param codigo_postal
	 * @param telefono
	 * @param movil
	 * @param email
	 */
    
    public Perfil (String userId, String nombre, String direccion, String poblacion,
	String provincia, String codigo_postal, String telefono, String movil, String email) {
    	this.userId = userId;
    	this.nombre = nombre;
    	this.direccion = direccion;
    	this.poblacion = poblacion;
    	this.provincia = provincia;
    	this.codigo_postal = codigo_postal;
    	this.telefono = telefono;
    	this.movil = movil;
    	this.email = email;
    }
    

    /**
     * Getters
     */
    
	public String getNombre() {
		return nombre;
	}

	public String getEmail() {
		return email;
	}

	public String getUserId() {
		return userId;
	}
	
	public String getDireccion() {
		return direccion;
	}

	public String getPoblacion() {
		return poblacion;
	}

	public String getProvincia() {
		return provincia;
	}

	public String getCodigo_postal() {
		return codigo_postal;
	}

	public String getTelefono() {
		return telefono;
	}

	public String getMovil() {
		return movil;
	}

	public List<String> getMascotasPropiasKeys() {
        return ImmutableList.copyOf(mascotasPropiasKeys);
    }
	
	public List<String> getVisitasPropiasKeys() {
        return ImmutableList.copyOf(visitasPropiasKeys);
    }
	
	/**
	 * Actualización del perfil
	 * @param nombre
	 * @param direccion
	 * @param poblacion
	 * @param provincia
	 * @param codigo_postal
	 * @param telefono
	 * @param movil
	 */
	public void update (String nombre, String direccion, String poblacion,
			String provincia, String codigo_postal, String telefono, String movil){
		if(nombre!=null){
			this.nombre=nombre;
		}
		if(direccion!=null){
			this.direccion=direccion;
		}
		if(poblacion!=null){
			this.poblacion=poblacion;
		}
		if(provincia!=null){
			this.provincia=provincia;
		}
		if(codigo_postal!=null){
			this.codigo_postal=codigo_postal;
		}
		if(telefono!=null){
			this.telefono=telefono;
		}
		if(movil!=null){
			this.movil=movil;
		}
		
	}

    /**
     * Añadir mascotas al usuario
     * @param mascotaKey
     */
    public void addAMascotasPropiasKeys(String mascotaKey) {
    	mascotasPropiasKeys.add(mascotaKey);
    }
    
    /**
     * Eliminar mascotas del usuario
     * @param mascotaKey
     */
    public void eliminarMascota(String mascotaKey) {
        if (mascotasPropiasKeys.contains(mascotaKey)) {
        	mascotasPropiasKeys.remove(mascotaKey);
        } else {
            throw new IllegalArgumentException("Mascota incorrecta: " + mascotaKey);
        }
    }
    
    /**
     * Añadir visitas al usuario
     * @param visitasKey
     */
    public void addVisitasPropiasKeys(String visitasKey) {
    	visitasPropiasKeys.add(visitasKey);
    }
    
    /**
     * Eliminar visitas del usuario
     * @param visitasKey
     */
    public void eliminarVisita(String visitaKey) {
        if (visitasPropiasKeys.contains(visitaKey)) {
        	visitasPropiasKeys.remove(visitaKey);
        } else {
            throw new IllegalArgumentException("Visita incorrecta: " + visitaKey);
        }
    }

}
