'use strict';

/**
 * Módulo raíz de veterinarioApp.
 *
 * @type {veterinarioApp|*|{}}
 */
var veterinarioApp = veterinarioApp || {};

/**
 * @ngdoc module
 * @name veterinarioControles
 *
 * @description
 * Módulo Angular para configurar los controllers.
 *
 */
veterinarioApp.controllers = angular.module('veterinarioControles', ['ui.bootstrap']);

/**
 * @ngdoc controller
 * @name MiPerfilCtrl
 *
 * @description
 * Control usado para la página del perfil de usuario.
 */
veterinarioApp.controllers.controller('MiPerfilCtrl',
    function ($scope, $log, oauth2Provider, HTTP_ERRORS) {
        $scope.submitted = false;
        $scope.loading = false;
        $scope.messages='';

        /**
         * Perfil inicial obtenido del servidor.
         * @type {{}}
         */
        $scope.perfilInicial = {};
        
        
        /**
         * Inicialización de la página del perfil
         * Actualiza el perfil si ha sido guardado
         */
        $scope.init = function () {
            $scope.messages='';
            var recuperarPerfil = function () {
                $scope.perfil = {};
                $scope.loading = true;
                gapi.client.veterinario.getPerfil().
                    execute(function (resp) {
                        $scope.$apply(function () {
                            
                            if (resp.error) {
                                // Fallo al cargar el perfil.
                            } else {
                            	$scope.perfilInicial.email = resp.result.email;
                            	$scope.perfil.email = $scope.perfilInicial.email;
                            	
                            	if (resp.result.nombre != null){
                            		$scope.perfil.nombre = resp.result.nombre;
                            		$scope.perfilInicial.nombre = resp.result.nombre;
                            		$scope.loading = false;
                            		$scope.perfil.direccion = resp.result.direccion;
                                    $scope.perfil.poblacion = resp.result.poblacion;
                                    $scope.perfil.provincia = resp.result.provincia;
                                    $scope.perfil.codigo_postal = resp.result.codigo_postal;
                                    $scope.perfil.telefono = resp.result.telefono;
                                    $scope.perfil.movil = resp.result.movil;
                                    
                                    $scope.perfilInicial.direccion = resp.result.direccion;
                                    $scope.perfilInicial.poblacion = resp.result.poblacion;
                                    $scope.perfilInicial.provincia = resp.result.provincia;
                                    $scope.perfilInicial.codigo_postal = resp.result.codigo_postal;
                                    $scope.perfilInicial.telefono = resp.result.telefono;
                                    $scope.perfilInicial.movil = resp.result.movil;
                            	}else{
                            		$scope.nombreUsuarios();
                                    $scope.loading = false;
                            	}
                            }
                        });
                    }
                );
            };
            if (!oauth2Provider.signedIn) {
                var modalInstance = oauth2Provider.showLoginModal();
                modalInstance.result.then(recuperarPerfil);
            } else {
            	recuperarPerfil();
            }

            $scope.nombreUsuarios = function(){
                $scope.messages='';
        		gapi.client.veterinario.consultaUsuario().
                execute(function (resp2) {
                    $scope.$apply(function () {
                        $scope.loading = false;
                        if (resp2.error) {
                        	$scope.messages = 'ERROR!!!! : ' + errorMessage;
                            $scope.alertStatus = 'warning';
                        } else {
                            var nombre_usuario = [];
                            angular.forEach(resp2.items, function (user) {
                                nombre_usuario.push(user);
                            });
                            $scope.perfilInicial.nombre = nombre_usuario.toString();
                            $scope.perfil.nombre = $scope.perfilInicial.nombre;                            
                            $scope.perfil.direccion = resp.result.direccion;
                            $scope.perfil.poblacion = resp.result.poblacion;
                            $scope.perfil.provincia = resp.result.provincia;
                            $scope.perfil.codigo_postal = resp.result.codigo_postal;
                            $scope.perfil.telefono = resp.result.telefono;
                            $scope.perfil.movil = resp.result.movil;
                            
                            $scope.perfilInicial.direccion = resp.result.direccion;
                            $scope.perfilInicial.poblacion = resp.result.poblacion;
                            $scope.perfilInicial.provincia = resp.result.provincia;
                            $scope.perfilInicial.codigo_postal = resp.result.codigo_postal;
                            $scope.perfilInicial.telefono = resp.result.telefono;
                            $scope.perfilInicial.movil = resp.result.movil;
                        }
                        }
                    )}
                )};
        };

        $scope.guardarPerfil = function () {
            $scope.messages='';
            $scope.submitted = true;
            $scope.loading = true;
            gapi.client.veterinario.guardarPerfil($scope.perfil).
                execute(function (resp) {
                    $scope.$apply(function () {
                        $scope.loading = false;
                        if (resp.error) {
                            // Si falla al guardar el perfil.
                            var errorMessage = resp.error.message || '';
                            $scope.messages = 'Fallo al actualizar el perfil : ' + errorMessage + JSON.stringify($scope.perfil);
                            $scope.alertStatus = 'warning';
                            
                            if (resp.code && resp.code == HTTP_ERRORS.UNAUTHORIZED) {
                                oauth2Provider.showLoginModal();
                                return;
                            }
                        } else {
                            //Cuando se guarda correctamente.
                            $scope.messages = 'El perfil ha sido actualizado';
                            $scope.alertStatus = 'success';
                            $scope.submitted = false;
                            $scope.perfilInicial = {
                                nombre: $scope.perfil.nombre,
                                direccion: $scope.perfil.direccion,
                                poblacion: $scope.perfil.poblacion,
                                provincia: $scope.perfil.provincia,
                                codigo_postal: $scope.perfil.codigo_postal,
	                            telefono: $scope.perfil.telefono,
	                            movil: $scope.perfil.movil
    
                            };

                            $log.info($scope.messages + JSON.stringify(resp.result));
                        }
                    });
                });
        };
    })
;

/**
 * @ngdoc controller
 * @name CrearMascotaCtrl
 *
 * @description
 * Control usado para la página de crear mascotas.
 */
veterinarioApp.controllers.controller('CrearMascotaCtrl',
    function ($scope, $log, oauth2Provider, HTTP_ERRORS, $location) {
		$scope.messages='';

        $scope.mascota = $scope.mascota || {};

        $scope.tiposDeAnimales = function () {
    		$scope.tiposAnimales = [
    		      'Perro',
    		      'Gato',
    		      'Equino',
    		      'Ave',
    		      'Roedor',
    		      'Pez',
    		      'Reptil',
    		      'Anfibio',
    		      'Otro'
    		];
        };

        $scope.sexoDeAnimales = function () {
    		$scope.sexoAnimales = [
    		      'Macho',
    		      'Hembra'
    		];
        };
   
        $scope.crearMascota = function (mascotaForm) {
            $scope.loading = true;
            $scope.messages='';
            gapi.client.veterinario.crearMascota($scope.mascota).
                execute(function (resp) {
                    $scope.$apply(function () {
                        $scope.loading = false;
                        if (resp.error) {
                            var errorMessage = resp.error.message || '';
                            $scope.messages = 'Fallo al crear la mascota : ' + errorMessage;
                            $scope.alertStatus = 'warning';
                            if (resp.code && resp.code == HTTP_ERRORS.UNAUTHORIZED) {
                            	var modalInstance = oauth2Provider.showLoginModal();
                                modalInstance.result.then($scope.crearMascota);
                            }
                        } else {
                            $scope.submitted = false;
                            $scope.mascota = {};
                            $location.path("/mascota");
                            $log.info($scope.messages + ' : ' + JSON.stringify(resp.result));
                        }
                        
                    });
                });
        };
        
        
    });

/**
 * @ngdoc controller
 * @name MostrarMascotaCtrl
 *
 * @description
 * Control usado para la página del listado de mascotas.
 */
veterinarioApp.controllers.controller('MostrarMascotaCtrl', 
		function ($scope, $log, oauth2Provider, HTTP_ERRORS) {
    $scope.messages='';

    $scope.submitted = false;
    
    $scope.selectedTab = 'TUS MASCOTAS';

   $scope.filters = [
    ];

    $scope.filtereableFields = [
        {enumValue: 'NOMBRE', displayName: 'Nombre Mascota'}
    ]

    $scope.operators = [
        {displayName: '=', enumValue: 'EQ'},
        {displayName: '!=', enumValue: 'NE'}
    ];

    $scope.mascotas = [];

    /**
     * Contiene el estado si offcanvas está activado.
     *
     * @type {boolean}
     */
    $scope.isOffcanvasEnabled = false;
    	    
    $scope.tabYouHaveCreatedSelected = function () {
        $scope.selectedTab = 'TUS MASCOTAS';
        $scope.consultaMascotas();
    };

    /**
     * Cambia el estado de offcanvas.
     */
    $scope.toggleOffcanvas = function () {
        $scope.isOffcanvasEnabled = !$scope.isOffcanvasEnabled;
    };

    /**
     * Namespace para la paginación.
     * @type {{}|*}
     */
    $scope.pagination = $scope.pagination || {};
    $scope.pagination.currentPage = 0;
    $scope.pagination.pageSize = 5;
    
    /**
     * Devuelve el número de páginas en la paginación.
     * @returns {number}
     */
    $scope.pagination.numberOfPages = function () {
        return Math.ceil($scope.mascotas.length / $scope.pagination.pageSize);
    };

    /**
     * Devuelve un array incluyendo los números del 1 al número de páginas.
     * @returns {Array}
     */
    $scope.pagination.pageArray = function () {
        var pages = [];
        var numberOfPages = $scope.pagination.numberOfPages();
        for (var i = 0; i < numberOfPages; i++) {
            pages.push(i);
        }
        return pages;
    };

    /**
     * Comprueba si el elemento de destino que invoca el evento click tiene la clase "disabled".
     */
    $scope.pagination.isDisabled = function (event) {
        return angular.element(event.target).hasClass('disabled');
    }

    /**
     * Añade un filtro y establece el valor predeterminado.
     */
    $scope.addFilter = function () {
        $scope.filters.push({
            field: $scope.filtereableFields[0],
            operator: $scope.operators[0],
            value: ''
        })
    };

    /**
     * Borra todos los filtros y recarga la página
     */
    $scope.clearFilters = function () {
        $scope.filters = [];
        $scope.tabYouHaveCreatedSelected();
    };

    /**
     * Elimina el filtro indicado por el índice desde $scope.filters
     * @param index
     */
    $scope.removeFilter = function (index) {
        if ($scope.filters[index]) {
            $scope.filters.splice(index, 1);
            $scope.filtroMascotas();
        }
    };

    /**
     * Consulta las mascotas
     */
     $scope.consultaMascotas = function () {
    	    $scope.submitted = false;
            $scope.consultaTusMascotas();
      };

     /**
     * Invoca el método de la api getMascotasCreadas
     */
    $scope.consultaTusMascotas = function () {
        $scope.messages='';
        $scope.loading = true;
        gapi.client.veterinario.getMascotasCreadas().
            execute(function (resp) {
                $scope.$apply(function () {
                    $scope.loading = false;
                    if (resp.error) {
                        var errorMessage = resp.error.message || '';
                        $scope.messages = 'Fallo al consultar tus mascotas : ' + errorMessage;
                        $scope.alertStatus = 'warning';
                        $log.error($scope.messages);

                        if (resp.code && resp.code == HTTP_ERRORS.UNAUTHORIZED) {
                        	var modalInstance = oauth2Provider.showLoginModal();
                            modalInstance.result.then($scope.tabYouHaveCreatedSelected);
                        }
                    } else {
                        $scope.submitted = false;
                        $log.info($scope.messages);
                        $scope.mascotas = [];
                        angular.forEach(resp.items, function (mascota) {
                            $scope.mascotas.push(mascota);
                        });
                    }
                    $scope.submitted = true;
                });
            });
    };

    /**
     * Añade los filtros
     */
    $scope.filtroMascotas = function () {
    	var sendFilters = {
                filters: []
        }
        for (var i = 0; i < $scope.filters.length; i++) {
                var filter = $scope.filters[i];
                if (filter.field && filter.operator && filter.value) {
                    sendFilters.filters.push({
                        field: filter.field.enumValue,
                        operator: filter.operator.enumValue,
                        value: filter.value
                    });
                    
                }
        }
    	//Si no se han añadido filtros recarga la página
    	if (i < 1){
    		$scope.tabYouHaveCreatedSelected();
    	}else{
    		$scope.messages='';
            $scope.loading = true;
            gapi.client.veterinario.consultaMascotas(sendFilters).
                execute(function (resp) {
                    $scope.$apply(function () {
                        $scope.loading = false;
                        if (resp.error) {
                            var errorMessage = resp.error.message || '';
                            $scope.messages = 'Fallo al consultar tus mascotas : ' + ' filtros: ' + JSON.stringify(sendFilters) + errorMessage;
                            $scope.alertStatus = 'warning';
                            $log.error($scope.messages + ' filtros: ' + JSON.stringify(sendFilters));

                         } else {
                            $scope.submitted = false;
                            $log.info($scope.messages + ' filtros: ' + JSON.stringify(sendFilters));

                            $scope.mascotas = [];
                            angular.forEach(resp.items, function (mascota) {
                                $scope.mascotas.push(mascota);
                                
                            });
                        }
                        $scope.submitted = true;
                    });
                });
    	}
    	
    };

});

/**
 * @ngdoc controller
 * @name DetallesMascotaCtrl
 *
 * @description
 * Control utilizado en la página de los detalles de la mascota.
 */
veterinarioApp.controllers.controller('DetallesMascotaCtrl', function ($scope, $log, $routeParams, HTTP_ERRORS, $location) {
    $scope.messages='';
    $scope.submitted = false;
    $scope.loading =  false;
    $scope.mascotaInicial = {};

    $scope.tiposDeAnimales = function () {
		$scope.tiposAnimales = [
  		      'Perro',
		      'Gato',
		      'Equino',
		      'Ave',
		      'Roedor',
		      'Pez',
		      'Reptil',
		      'Anfibio',
		      'Otro'
		];
    };

    $scope.sexoDeAnimales = function () {
		$scope.sexoAnimales = [
		      'Macho',
		      'Hembra'
		];
    };
    
    /**
     * Obtiene los datos de la mascota
     */
    $scope.init = function () {
       var recuperarMascota = function (){
           $scope.messages='';
    	   $scope.loading = true;
           $scope.mascota = {};
    	   gapi.client.veterinario.getMascota({
               websafeMascotaKey: $routeParams.websafeMascotaKey
           }).execute(function (resp) {
               $scope.$apply(function () {
                   $scope.loading = false;
                   if (resp.error) {
                       var errorMessage = resp.error.message || '';
                       $scope.messages = 'Fallo al cargar la mascota : ' + $routeParams.websafeMascotaKey
                           + ' ' + errorMessage;
                       $scope.alertStatus = 'warning';
                       $log.error($scope.messages);
                   } else {
                       $scope.mascota.nombre = resp.result.nombre;
                       $scope.mascota.fecha_nacimiento = $scope.convertirFecha(resp.result.fecha_nacimiento);
                       $scope.mascota.tipo_animal = resp.result.tipo_animal;
                       $scope.mascota.raza = resp.result.raza;
                       $scope.mascota.sexo = resp.result.sexo;
                       $scope.mascota.color = resp.result.color;
                       $scope.mascota.esterilizado = resp.result.esterilizado;
                       $scope.mascota.num_microchip = resp.result.num_microchip;
                       $scope.mascota.fecha_microchip = $scope.convertirFecha(resp.result.fecha_microchip);
                       $scope.mascota.num_pasaporte = resp.result.num_pasaporte;
                       $scope.mascota.num_registro = resp.result.num_registro;
                       $scope.mascota.fecha_registro = $scope.convertirFecha(resp.result.fecha_registro);
                       $scope.mascota.num_poliza = resp.result.num_poliza;
                       $scope.mascota.validez = $scope.convertirFecha(resp.result.validez);
                       
                       $scope.mascotaInicial = resp.result;
                       $scope.mascotaInicial.fecha_nacimiento = $scope.convertirFecha(resp.result.fecha_nacimiento);
                       $scope.mascotaInicial.fecha_microchip = $scope.convertirFecha(resp.result.fecha_microchip);
                       $scope.mascotaInicial.fecha_registro = $scope.convertirFecha(resp.result.fecha_registro);
                       $scope.mascotaInicial.validez = $scope.convertirFecha(resp.result.validez);
                       
                   }
               });
           })
    	   
       };
       recuperarMascota();

       $scope.convertirFecha = function(date){
    	   var d = new Date(date);
           if (d.getMonth()+1 <= 9 && d.getDate()<=9){
        	   var datestring = d.getFullYear() + "-0" + (d.getMonth()+1) + "-0" + d.getDate();
           }else if(d.getMonth()+1 <= 9 && d.getDate()> 9){
        	   var datestring = d.getFullYear() + "-0" + (d.getMonth()+1) + "-" + d.getDate();
           }else if(d.getMonth()+1 > 9 && d.getDate()<=9){
        	   var datestring = d.getFullYear() + "-" + (d.getMonth()+1) + "-0" + d.getDate();
           }else{
        	   var datestring = d.getFullYear() + "-" + (d.getMonth()+1) + "-" + d.getDate();
           }
           return datestring;
       }
       
    }; 
    
    /**
     * Actualiza la mascota
     */
    $scope.updateMascota = function (mascotaForm){
        $scope.submitted = true;
    	$scope.loading = true;
        $scope.messages='';
        if ($scope.mascota.fecha_nacimiento == "NaN-NaN-NaN" || $scope.mascota.fecha_nacimiento ==""){
        	$scope.mascota.fecha_nacimiento = null;
        	$scope.mascotaInicial.fecha_nacimiento = null;
        }
        if ($scope.mascota.fecha_microchip == "NaN-NaN-NaN" || $scope.mascota.fecha_microchip == ""){
        	$scope.mascota.fecha_microchip = null;
        	$scope.mascotaInicial.fecha_microchip= null;
        }
        if ($scope.mascota.fecha_registro == "NaN-NaN-NaN" || $scope.mascota.fecha_registro == ""){
        	$scope.mascota.fecha_registro = null;
        	$scope.mascotaInicial.fecha_registro= null;
        }
        if ($scope.mascota.validez == "NaN-NaN-NaN" || $scope.mascota.validez == ""){
        	$scope.mascota.validez = null;
        	$scope.mascotaInicial.validez= null;
        }
        
    	gapi.client.veterinario.updateMascota({
    			websafeMascotaKey: $routeParams.websafeMascotaKey,
    			nombre: $scope.mascota.nombre,
                fecha_nacimiento: $scope.mascota.fecha_nacimiento,
                tipo_animal: $scope.mascota.tipo_animal,
                raza: $scope.mascota.raza,
                sexo: $scope.mascota.sexo,
                color: $scope.mascota.color,
                esterilizado: $scope.mascota.esterilizado,
                num_microchip: $scope.mascota.num_microchip,
                fecha_microchip: $scope.mascota.fecha_microchip,
                num_pasaporte: $scope.mascota.num_pasaporte,
                num_registro: $scope.mascota.num_registro,
                fecha_registro: $scope.mascota.fecha_registro,
                num_poliza: $scope.mascota.num_poliza,
                validez: $scope.mascota.validez
    	}).execute(function(resp){
            
    		$scope.$apply(function(){

    			$scope.loading = false;
    			if (resp.error){
    				var errorMessage = resp.error.message || '';
                    $scope.messages = 'Fallo al actualizar la mascota : ' + errorMessage+"f.n"+$scope.mascota.fecha_nacimiento;
                    $scope.alertStatus = 'warning';
                    
    			}else{
    				$scope.messages = 'La mascota ha sido actualizada';
                    $scope.alertStatus = 'success';
                    $scope.submitted = false;
                    $scope.mascotaInicial = {
                        nombre: $scope.mascota.nombre,
                        fecha_nacimiento: $scope.mascota.fecha_nacimiento,
                        tipo_animal: $scope.mascota.tipo_animal,
                        raza: $scope.mascota.raza,
                        sexo: $scope.mascota.sexo,
                        color: $scope.mascota.color,
                        esterilizado: $scope.mascota.esterilizado,
                        num_microchip: $scope.mascota.num_microchip,
                        fecha_microchip: $scope.mascota.fecha_microchip,
                        num_pasaporte: $scope.mascota.num_pasaporte,
                        num_registro: $scope.mascota.num_registro,
                        fecha_registro: $scope.mascota.fecha_registro,
                        num_poliza: $scope.mascota.num_poliza,
                        validez: $scope.mascota.validez
                    };
                    
                    $log.info($scope.messages + JSON.stringify(resp.result));
    				
    			}
    		});
    		
    	});
    	
    };



  /**
   * Elimina mascota
   */
   $scope.eliminarMascota = function () {
        $scope.loading = true;
        $scope.messages='';
        gapi.client.veterinario.eliminarMascota({
            websafeMascotaKey: $routeParams.websafeMascotaKey
        }).execute(function (resp) {
            $scope.$apply(function () {
                $scope.loading = false;
                if (resp.error) {
                    var errorMessage = resp.error.message || '';
                    $scope.messages = 'Fallo al eliminar la mascota : ' + errorMessage;
                    $scope.alertStatus = 'warning';
                    $log.error($scope.messages);
                    if (resp.code && resp.code == HTTP_ERRORS.UNAUTHORIZED) {
                        oauth2Provider.showLoginModal();
                        return;
                    }
                } else {
                    if (resp.result) {
                        $scope.messages = 'Mascota eliminada';
                        $scope.alertStatus = 'success';
                        $location.path("/mascota");
                        $log.info($scope.messages);
                    } else {
                        var errorMessage = resp.error.message || '';
                        $scope.messages = 'Fallo al eliminar la mascota';
                        $scope.alertStatus = 'warning';
                        $log.error($scope.messages);
                    }
                }
            });
        });
    };

});

/**
 * @ngdoc controller
 * @name CrearVisitaCtrl
 *
 * @description
 * Control utilizado en la página de crear visitas.
 */
veterinarioApp.controllers.controller('CrearVisitaCtrl',
    function ($scope, $log, oauth2Provider, HTTP_ERRORS, $location) {
		$scope.messages='';

        $scope.visita = $scope.visita || {};

        $scope.centrosVeterinarios = function () {
    		$scope.nuentros_centros = [
     		      'Centro Veterinario Alcoy',
    		      'Centro Veterinario Cocentaina',
    		      'Centro Veterinario Muro',
    		      'Centro Veterinario Ibi'
    		];
        };


    $scope.consultaNombreTusMascotas = function () {
        $scope.loading = true;
        $scope.messages='';
        gapi.client.veterinario.getNombreMascotasCreadas().
            execute(function (resp) {
                $scope.$apply(function () {
                    $scope.loading = false;
                    if (resp.error) {
                        var errorMessage = resp.error.message || '';
                        $scope.messages = 'Fallo al consultar tus mascotas : ' + errorMessage;
                        $scope.alertStatus = 'warning';
                        $log.error($scope.messages);

                        if (resp.code && resp.code == HTTP_ERRORS.UNAUTHORIZED) {
                        	var modalInstance = oauth2Provider.showLoginModal();
                            modalInstance.result.then($scope.consultaNombreTusMascotas);
                        }
                    } else {

                        $log.info($scope.messages);
                        $scope.submitted = false;
                        
                        $scope.nombres_mascotas = [];
                        angular.forEach(resp.items, function (mascota) {
                            $scope.nombres_mascotas.push(mascota);
                        });
                        //Si no tiene mascotas no puede registrar visitas
                        if ($scope.nombres_mascotas == ""){
                            $location.path("/no_mascota");
                        }

                    }
                    $scope.submitted = true;
                });
            });
    };
	
	
		$scope.validaFechas = function(){
			$scope.messages='';
			if ($scope.visita.proxima_visita == null){
				return true;
			}else if ($scope.visita.fecha_visita <= $scope.visita.proxima_visita){
				return true;
			}else{
				return false;
			}
		}
    
    
    	$scope.validaVisita = function(visitaForm){
			return $scope.validaFechas();
		}
	
	
        $scope.crearVisita = function (visitaForm) {
        	$scope.messages='';
        	if ($scope.validaVisita(visitaForm) == false){
        		$scope.messages = 'La fecha de la próxima visita no puede ser anterior a la de la visita registrada.';
                $scope.alertStatus = 'warning';
        		return;
        	}
        	
            $scope.loading = true;
            gapi.client.veterinario.crearVisita($scope.visita).
                execute(function (resp) {
                    $scope.$apply(function () {
                        $scope.loading = false;
                        $scope.messages='';
                        if (resp.error) {
                            var errorMessage = resp.error.message || '';
                            $scope.messages = 'Fallo al crear la visita : ' + errorMessage;
                            $scope.alertStatus = 'warning';
                            $log.error($scope.messages + ' Visita : ' + JSON.stringify($scope.visita));

                            if (resp.code && resp.code == HTTP_ERRORS.UNAUTHORIZED) {
                            	return;
                            }
                        } else {
                            $scope.submitted = false;
                            $scope.visita = {};
                            $location.path("/visita");
                            $log.info($scope.messages + ' : ' + JSON.stringify(resp.result));
                        }
                    });
                });
        };
    });

/**
 * @ngdoc controller
 * @name MostrarVisitaCtrl
 *
 * @description
 * Control utilizado en la página del listado de visitas.
 */
veterinarioApp.controllers.controller('MostrarVisitaCtrl', 
		function ($scope, $log, oauth2Provider, HTTP_ERRORS) {
	$scope.messages='';

    $scope.submitted = false;
    
    $scope.selectedTab = 'LISTADO DE TUS VISITAS';

    $scope.filters = [
    ];

    $scope.filtereableFields = [
        {enumValue: 'VETERINARIO', displayName: 'Veterinario'},
        {enumValue: 'NOMBRE_MASCOTA', displayName: 'Nombre Mascota'}
    ]

    $scope.operators = [
        {displayName: '=', enumValue: 'EQ'},
        {displayName: '!=', enumValue: 'NE'}
    ];

    $scope.visitas = [];

    $scope.isOffcanvasEnabled = false;

    $scope.tabYouHaveCreatedSelected = function () {
        $scope.selectedTab = 'LISTADO DE TUS VISITAS';
        $scope.consultaVisitas();
    };

    $scope.toggleOffcanvas = function () {
        $scope.isOffcanvasEnabled = !$scope.isOffcanvasEnabled;
    };

    /**
     * Paginación
     */
    $scope.pagination = $scope.pagination || {};
    $scope.pagination.currentPage = 0;
    $scope.pagination.pageSize = 10;

    $scope.pagination.numberOfPages = function () {
        return Math.ceil($scope.visitas.length / $scope.pagination.pageSize);
    };

    $scope.pagination.pageArray = function () {
        var pages = [];
        var numberOfPages = $scope.pagination.numberOfPages();
        for (var i = 0; i < numberOfPages; i++) {
            pages.push(i);
        }
        return pages;
    };

    $scope.pagination.isDisabled = function (event) {
        return angular.element(event.target).hasClass('disabled');
    }

    $scope.addFilter = function () {
        $scope.filters.push({
            field: $scope.filtereableFields[0],
            operator: $scope.operators[0],
            value: ''
        })
    };

   $scope.clearFilters = function () {
        $scope.filters = [];
        $scope.tabYouHaveCreatedSelected();
    };

   $scope.removeFilter = function (index) {
        if ($scope.filters[index]) {
            $scope.filters.splice(index, 1);
            $scope.filtroVisitas();
        }
    };

    $scope.consultaVisitas = function () {
        $scope.submitted = false;
        $scope.consultaTusVisitas();
         
    };

    $scope.consultaTusVisitas = function () {
        $scope.loading = true;
        $scope.messages='';
        gapi.client.veterinario.getVisitasCreadas().
            execute(function (resp) {
                $scope.$apply(function () {
                    $scope.loading = false;
                    if (resp.error) {
                        var errorMessage = resp.error.message || '';
                        $scope.messages = 'Fallo al consultar tus visitas : ' + errorMessage;
                        $scope.alertStatus = 'warning';
                        $log.error($scope.messages);

                        if (resp.code && resp.code == HTTP_ERRORS.UNAUTHORIZED) {
                        	var modalInstance = oauth2Provider.showLoginModal();
                            modalInstance.result.then($scope.tabYouHaveCreatedSelected);
                        }
                    } else {
                        $scope.submitted = false;
                        $log.info($scope.messages);

                        $scope.visitas = [];
                        angular.forEach(resp.items, function (visita) {
                            $scope.visitas.push(visita);
                        });
                    }
                    $scope.submitted = true;
                });
            });
    };

    $scope.filtroVisitas = function () {
    	var sendFilters = {
                filters: []
        }
        for (var i = 0; i < $scope.filters.length; i++) {
                var filter = $scope.filters[i];
                if (filter.field && filter.operator && filter.value) {
                    sendFilters.filters.push({
                        field: filter.field.enumValue,
                        operator: filter.operator.enumValue,
                        value: filter.value
                    });
                    
                }
        }

    	if (i < 1){
    		$scope.tabYouHaveCreatedSelected();
    	}else{
    		$scope.messages='';
            $scope.loading = true;
            gapi.client.veterinario.consultaVisitas(sendFilters).
                execute(function (resp) {
                    $scope.$apply(function () {
                        $scope.loading = false;
                        if (resp.error) {
                            var errorMessage = resp.error.message || '';
                            $scope.messages = 'Fallo al consultar tus visitas : ' + ' filtros: ' + JSON.stringify(sendFilters) + errorMessage;
                            $scope.alertStatus = 'warning';
                            $log.error($scope.messages + ' filtros: ' + JSON.stringify(sendFilters));

                         } else {
                            $scope.submitted = false;
                            $log.info($scope.messages + ' filtros: ' + JSON.stringify(sendFilters));

                            $scope.visitas = [];
                            angular.forEach(resp.items, function (visita) {
                                $scope.visitas.push(visita);
                                
                            });
                       
                            
                        }
                        $scope.submitted = true;
                    });
                });
    	}
    	
    };
});

/**
 * @ngdoc controller
 * @name DetallesVisitaCtrl
 *
 * @description
 * Control utilizado en la página de los detalles de la visita
 */
veterinarioApp.controllers.controller('DetallesVisitaCtrl', function ($scope, $log, $routeParams, HTTP_ERRORS, $location) {
	$scope.messages='';
    $scope.submitted = false;
    $scope.loading =  false;
    $scope.visitaInicial = {};

    $scope.centrosVeterinarios = function () {
		$scope.nuentros_centros = [
		      'Centro Veterinario Alcoy',
		      'Centro Veterinario Cocentaina',
		      'Centro Veterinario Muro',
		      'Centro Veterinario Ibi'
		];
    };

    $scope.init = function () {
       var recuperarVisita = function (){
    	   $scope.loading = true;
    	   $scope.messages='';
           $scope.visita = {};
    	   gapi.client.veterinario.getVisita({
               websafeVisitaKey: $routeParams.websafeVisitaKey
           }).execute(function (resp) {
               $scope.$apply(function () {
                   $scope.loading = false;
                   if (resp.error) {
                       var errorMessage = resp.error.message || '';
                       $scope.messages = 'Fallo al cargar la visita : ' + $routeParams.websafeVisitaKey
                           + ' ' + errorMessage;
                       $scope.alertStatus = 'warning';
                       $log.error($scope.messages);
                   } else {
                       $scope.visita.fecha_visita = resp.result.fecha_visita;
                       $scope.visita.hora_visita = resp.result.hora_visita;
                       $scope.visita.nombre_mascota = resp.result.nombre_mascota;
                       $scope.visita.veterinario = resp.result.veterinario;
                       $scope.visita.centro_veterinario = resp.result.centro_veterinario;
                       $scope.visita.peso = resp.result.peso;
                       $scope.visita.vacunas = resp.result.vacunas;
                       $scope.visita.analisis = resp.result.analisis;
                       $scope.visita.radiografias = resp.result.radiografias;
                       $scope.visita.exploracion = resp.result.exploracion;
                       $scope.visita.otras_observaciones = resp.result.otras_observaciones;
                       $scope.visita.proxima_visita = $scope.convertirFecha2(resp.result.proxima_visita);
                       $scope.visita.hora_prox_visita = resp.result.hora_prox_visita;
                      
                       $scope.visitaInicial = resp.result;
                       $scope.visitaInicial.proxima_visita = $scope.convertirFecha2(resp.result.proxima_visita);
                   }
               });
           })
    	   
       };
       recuperarVisita();

       $scope.convertirFecha2 = function(date){
    	   var d = new Date(date);
           if (d.getMonth()+1 <= 9 && d.getDate()<=9){
        	   var datestring = d.getFullYear() + "-0" + (d.getMonth()+1) + "-0" + d.getDate();
           }else if(d.getMonth()+1 <= 9 && d.getDate()> 9){
        	   var datestring = d.getFullYear() + "-0" + (d.getMonth()+1) + "-" + d.getDate();
           }else if(d.getMonth()+1 > 9 && d.getDate()<=9){
        	   var datestring = d.getFullYear() + "-" + (d.getMonth()+1) + "-0" + d.getDate();
           }else{
        	   var datestring = d.getFullYear() + "-" + (d.getMonth()+1) + "-" + d.getDate();
           }
           return datestring;
       }
       
    }; 
    
    /**
     * Actualización de la visita
     */
    $scope.updateVisita = function (visitaForm){
        $scope.submitted = true;
    	$scope.loading = true;
    	$scope.messages='';
    	if ($scope.visita.proxima_visita == "NaN-NaN-NaN" || $scope.visita.proxima_visita ==""){
    		$scope.visita.proxima_visita = null;
    		$scope.visita.hora_prox_visita = null;
        	$scope.visitaInicial.proxima_visita = null;
        	$scope.visitaInicial.hora_prox_visita = null;
        }
    	gapi.client.veterinario.updateVisita({
    			websafeVisitaKey: $routeParams.websafeVisitaKey,
                fecha_visita: $scope.visita.fecha_visita,
                hora_visita: $scope.visita.hora_visita,
		        nombre_mascota: $scope.visita.nombre_mascota,
		        veterinario: $scope.visita.veterinario,
		        centro_veterinario: $scope.visita.centro_veterinario,
		        peso: $scope.visita.peso,
		        vacunas: $scope.visita.vacunas,
		        analisis: $scope.visita.analisis,
		        radiografias: $scope.visita.radiografias,
		        exploracion: $scope.visita.exploracion,
		        otras_observaciones: $scope.visita.otras_observaciones,
		        proxima_visita: $scope.visita.proxima_visita,
		        hora_prox_visita: $scope.visita.hora_prox_visita
    	}).execute(function(resp){
    		$scope.$apply(function(){
    			$scope.messages='';
    			$scope.loading = false;
    			if (resp.error){
    				var errorMessage = resp.error.message || '';
                    $scope.messages = 'Fallo al actualizar la visita : ' + errorMessage;
                    $scope.alertStatus = 'warning';
                    $log.error($scope.messages + 'Visita : ' + JSON.stringify($scope.visita));
    			}else{
    				$scope.messages = 'La visita ha sido actualizada';
                    $scope.alertStatus = 'success';
                    $scope.submitted = false;
                    $scope.visitaInicial = {
                    		fecha_visita: $scope.visita.fecha_visita,
                    		hora_visita: $scope.visita.hora_visita,
            		        nombre_mascota: $scope.visita.nombre_mascota,
            		        veterinario: $scope.visita.veterinario,
            		        centro_veterinario: $scope.visita.centro_veterinario,
            		        peso: $scope.visita.peso,
            		        vacunas: $scope.visita.vacunas,
            		        analisis: $scope.visita.analisis,
            		        radiografias: $scope.visita.radiografias,
            		        exploracion: $scope.visita.exploracion,
            		        otras_observaciones: $scope.visita.otras_observaciones,
            		        proxima_visita: $scope.visita.proxima_visita,
            		        hora_prox_visita: $scope.visita.hora_prox_visita
                    };
                    
                    $log.info($scope.messages + JSON.stringify(resp.result));
    				
    			}
    		});
    		
    	});
    	
    };

    /**
     * Eliminar visita
     */
   $scope.eliminarVisita = function () {
        $scope.loading = true;
        $scope.messages='';
        gapi.client.veterinario.eliminarVisita({
            websafeVisitaKey: $routeParams.websafeVisitaKey
        }).execute(function (resp) {
            $scope.$apply(function () {
                $scope.loading = false;
                if (resp.error) {
                    var errorMessage = resp.error.message || '';
                    $scope.messages = 'Fallo al eliminar la visita : ' + errorMessage;
                    $scope.alertStatus = 'warning';
                    $log.error($scope.messages);
                    if (resp.code && resp.code == HTTP_ERRORS.UNAUTHORIZED) {
                        oauth2Provider.showLoginModal();
                        return;
                    }
                } else {
                    if (resp.result) {
                        $scope.messages = 'Visita eliminada';
                        $scope.alertStatus = 'success';
                        $location.path("/visita");
                        $log.info($scope.messages);
                    } else {
                        var errorMessage = resp.error.message || '';
                        $scope.messages = 'Fallo al eliminar la visita';
                        $scope.alertStatus = 'warning';
                        $log.error($scope.messages);
                    }
                }
            });
        });
    };

});

/**
 * @ngdoc controller
 * @name RootCtrl
 *
 * @description
 * El control raíz tiene un alcance del elemento body y los métodos utilizados en la aplicación 
 * como las autenticaciones de usuario.
 *
 */
veterinarioApp.controllers.controller('RootCtrl', function ($scope, $location, oauth2Provider) {

    $scope.isActive = function (viewLocation) {
        return viewLocation === $location.path();
    };

    $scope.getSignedInState = function () {
        return oauth2Provider.signedIn;
    };

    $scope.signIn = function () {
        oauth2Provider.signIn(function () {
            gapi.client.oauth2.userinfo.get().execute(function (resp) {
                $scope.$apply(function () {
                    if (resp.email) {
                    	$scope.messages='';
                        oauth2Provider.signedIn = true;
                    }
                });
            });
        });
    };

    $scope.initSignInButton = function () {
        gapi.signin.render('signInButton', {
            'callback': function () {
                jQuery('#signInButton button').attr('disabled', 'true').css('cursor', 'default');
                if (gapi.auth.getToken() && gapi.auth.getToken().access_token) {
                    $scope.$apply(function () {
                        oauth2Provider.signedIn = true;
                        $scope.messages='';
                    });
                }
            },
            'clientid': oauth2Provider.CLIENT_ID,
            'cookiepolicy': 'single_host_origin',
            'scope': oauth2Provider.SCOPES
        });
    };

    $scope.signOut = function () {
        oauth2Provider.signOut();
        $scope.messages='';
    };

    $scope.collapseNavbar = function () {
        angular.element(document.querySelector('.navbar-collapse')).removeClass('in');
    };
    
    $scope.mostrarModal =function(){
    	oauth2Provider.showLoginModal();
    };

});


/**
 * @ngdoc controller
 * @name OAuth2LoginModalCtrl
 *
 * @description
 * Control para el diálogo modal que aparece cuando un usuario necesita iniciar la sesión.
 *
 */
veterinarioApp.controllers.controller('OAuth2LoginModalCtrl',
    function ($scope, $modalInstance, $rootScope, oauth2Provider) {

		$scope.singInViaModal = function () {
            oauth2Provider.signIn(function () {
                gapi.client.oauth2.userinfo.get().execute(function (resp) {
                    $scope.$root.$apply(function () {
                        oauth2Provider.signedIn = true;
                        $scope.messages='';
                       
                    });

                    $modalInstance.close();
                });
            });
        };
    });








