'use strict';

/**
 * @ngdoc object
 * @name veterinarioApp
 * @requires $routeProvider
 * @requires veterinarioControles
 * @requires ui.bootstrap
 *
 * @description
 * Root app, controla las rutas y especifica el html y controlador, dependiendo de la URL solicitada.
 */
var app = angular.module('veterinarioApp',
    ['veterinarioControles', 'ngRoute', 'ui.bootstrap']).
    config(['$routeProvider',
        function ($routeProvider) {
            $routeProvider.
                when('/mascota', {
                    templateUrl: '/partials/listado_mascotas.html',
                    controller: 'MostrarMascotaCtrl'
                }).
                when('/mascota/crear', {
                    templateUrl: '/partials/crear_mascotas.html',
                    controller: 'CrearMascotaCtrl'
                }).
                when('/mascota/detail/:websafeMascotaKey', {
                    templateUrl: '/partials/detalles_mascotas.html',
                    controller: 'DetallesMascotaCtrl'
                }).
                when('/perfil', {
                    templateUrl: '/partials/perfil.html',
                    controller: 'MiPerfilCtrl'
                }).
                when('/visita', {
                    templateUrl: '/partials/listado_visitas.html',
                    controller: 'MostrarVisitaCtrl'
                }).
                when('/visita/crear', {
                    templateUrl: '/partials/crear_visitas.html',
                    controller: 'CrearVisitaCtrl'
                }).
                when('/visita/detail/:websafeVisitaKey', {
                    templateUrl: '/partials/detalles_visitas.html',
                    controller: 'DetallesVisitaCtrl'
                }).
                when('/no_mascota', {
                    templateUrl: '/partials/no_mascotas.html'
                }).
                when('/politica_privacidad', {
                    templateUrl: '/partials/politica_privacidad.html'
                }).
                when('/politica_cookies', {
                    templateUrl: '/partials/politica_cookies.html'
                }).
                when('/', {
                    templateUrl: '/partials/principal.html'
                }).
                otherwise({
                    redirectTo: '/'
                });
        }]);

/**
 * @ngdoc filter
 * @name startFrom
 *
 * @description
 * Un filtro que extrae el índice específico de un array.
 *
 */
app.filter('startFrom', function () {
    /**
     * Extracts an array from the specific index.
     *
     * @param {Array} data
     * @param {Integer} start
     * @returns {Array|*}
     */
    var filter = function (data, start) {
        return data.slice(start);
    }
    return filter;
});


/**
 * @ngdoc constant
 * @name HTTP_ERRORS
 *
 * @description
 * Contiene las constantes que representan los códigos de error HTTP.
 *
 */
app.constant('HTTP_ERRORS', {
    'UNAUTHORIZED': 401
});


/**
 * @ngdoc service
 * @name oauth2Provider
 *
 * @description
 * Servicio que contiene la información OAuth2 compartida a través de las páginas.
 *
 */
app.factory('oauth2Provider', function ($modal) {
    var oauth2Provider = {
        CLIENT_ID: '127872853905-vss2q5ph633jrvo7gh3fbf9bbb5q37h2.apps.googleusercontent.com',
        SCOPES: 'https://www.googleapis.com/auth/userinfo.email profile',
        signedIn: false
    };

    /**
     * Calls the OAuth2 authentication method.
     */
    oauth2Provider.signIn = function (callback) {
        gapi.auth.signIn({
            'clientid': oauth2Provider.CLIENT_ID,
            'cookiepolicy': 'single_host_origin',
            'accesstype': 'online',
            'approveprompt': 'auto',
            'scope': oauth2Provider.SCOPES,
            'callback': callback
        });
    };

    /**
     * Logs out the user.
     */
    oauth2Provider.signOut = function () {
        gapi.auth.signOut();
        // Explicitly set the invalid access token in order to make the API calls fail.
        gapi.auth.setToken({access_token: ''})
        oauth2Provider.signedIn = false;
    };

    /**
     * Shows the modal with Google+ sign in button.
     *
     * @returns {*|Window}
     */
    oauth2Provider.showLoginModal = function() {
        var modalInstance = $modal.open({
            templateUrl: '/partials/login.modal.html',
            controller: 'OAuth2LoginModalCtrl'
        });
        return modalInstance;
    };

    return oauth2Provider;
});
